import { generateTyping } from '../typing';
export function handleObject(schema, comment, options) {
    const required = schema.required ?? [];
    const properties = [];
    let dependencies = [];
    if (schema.properties) {
        for (const property of Object.keys(schema.properties)) {
            const td = generateTyping(schema.properties[property], options);
            properties.push(`${td.comment}${property}${required.includes(property) ? '' : '?'}: ${td.typeDeclaration}`);
            dependencies = dependencies.concat(td.typeDependencies);
        }
    }
    if (schema.additionalProperties !== false) {
        properties.push('[k: string]: unknown');
    }
    if (options.inline)
        return {
            typeDeclaration: `{${properties.join(', ')}}`,
            typeDependencies: dependencies,
            comment: comment,
        };
    else
        return {
            typeDeclaration: `{\n\t${properties.join('\n').replace(/\n/gi, '\n\t')}\n}`,
            typeDependencies: dependencies,
            comment: comment,
        };
}
//# sourceMappingURL=object.js.map